@@ -22,7 +22,7 @@ _unur_stdgen_student_init( struct unur_par *par, struct unur_gen *gen )
     _unur_cstd_set_sampling_routine( par,gen,_unur_stdgen_sample_student_tpol );
     return UNUR_SUCCESS;
   case 2:  
-    if (par->distr->data.cont.params[0] < 1.) {   
+    if (par!=NULL && par->distr->data.cont.params[0] < 1.) {   
       _unur_error(NULL,UNUR_ERR_GEN_CONDITION,"");
       return UNUR_ERR_GEN_CONDITION;
     }
