@@ -3,7 +3,9 @@
 
 UNUR_PAR *unur_pinv_new( const UNUR_DISTR *distribution );
 int unur_pinv_set_order( UNUR_PAR *parameters, int order);
+int unur_pinv_set_smoothness( UNUR_PAR *parameters, int smoothness);
 int unur_pinv_set_u_resolution( UNUR_PAR *parameters, double u_resolution);
+int unur_pinv_set_use_upoints( UNUR_PAR *parameters, int use_upoints );
 int unur_pinv_set_usepdf( UNUR_PAR *parameters );
 int unur_pinv_set_usecdf( UNUR_PAR *parameters );
 int unur_pinv_set_boundary( UNUR_PAR *parameters, double left, double right );
